@@ -56,7 +56,6 @@ use nodrop::NoDrop;
 
 mod array;
 mod array_string;
-mod char_ext;
 
 pub use array::Array;
 pub use odds::IndexRange as RangeArgument;
@@ -220,7 +219,7 @@ impl<A: Array> ArrayVec<A> {
         unsafe { // infallible
             // The spot to put the new value
             {
-                let p = self.get_unchecked_mut(index) as *mut _;
+                let p: *mut _ = self.get_unchecked_mut(index);
                 // Shift everything over to make space. (Duplicating the
                 // `index`th element into two consecutive places.)
                 ptr::copy(p, p.offset(1), len - index);
